# AA-EvePrices

Helper application designed to help developers managing the prices of Eve items through a common framework.

The data storing and querying is uniformized for developers.
However, the auth administrator stays in control of which provider (Fuzzwork, Janice, ...) will be used to populate the data.

## Currently supported providers:
- EveTycoon
- Fuzzwork
- Janice (experimental)


## Installation:

...
